aboutsummaryrefslogtreecommitdiffstats
path: root/arch/arc/include/asm/mach_desc.h
diff options
context:
space:
mode:
authorVineet Gupta <vgupta@synopsys.com>2015-10-13 15:26:00 +0530
committerVineet Gupta <vgupta@synopsys.com>2015-10-28 16:13:40 +0530
commit8721a7f5a6f95c38cacbe1be22c820a7698926ef (patch)
tree23edd43402fd28013cf0378ab03123c5838ea291 /arch/arc/include/asm/mach_desc.h
parentARCv2: smp: [plat-*]: No need to explicitly call mcip_init_early_smp() (diff)
downloadlinux-dev-8721a7f5a6f95c38cacbe1be22c820a7698926ef.tar.xz
linux-dev-8721a7f5a6f95c38cacbe1be22c820a7698926ef.zip
ARC: smp: Rename platform hook @init_smp -> @init_cpu_smp
This conveys better that it is called for each cpu Signed-off-by: Vineet Gupta <vgupta@synopsys.com>
Diffstat (limited to 'arch/arc/include/asm/mach_desc.h')
-rw-r--r--arch/arc/include/asm/mach_desc.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/arch/arc/include/asm/mach_desc.h b/arch/arc/include/asm/mach_desc.h
index 7c680910f104..6ff657a904b6 100644
--- a/arch/arc/include/asm/mach_desc.h
+++ b/arch/arc/include/asm/mach_desc.h
@@ -23,7 +23,7 @@
* @dt_compat: Array of device tree 'compatible' strings
* (XXX: although only 1st entry is looked at)
* @init_early: Very early callback [called from setup_arch()]
* @init_smp: for each CPU (e.g. setup IPI)
* [(M):init_IRQ(), (o):start_kernel_secondary()]
* @init_machine: arch initcall level callback (e.g. populate static
* platform devices or parse Devicetree)
@@ -35,7 +35,7 @@ struct machine_desc {
const char **dt_compat;
void (*init_early)(void);
#ifdef CONFIG_SMP
- void (*init_smp)(unsigned int);
+ void (*init_cpu_smp)(unsigned int);
#endif
void (*init_machine)(void);
void (*init_late)(void);
@@ -23,7 +23,7 @@
* (XXX: although only 1st entry is looked at)
* @init_early: Very early callback [called from setup_arch()]
- * @init_smp: for each CPU (e.g. setup IPI)
+ * @init_cpu_smp: for each CPU as it is coming up (SMP as well as UP)
* [(M):init_IRQ(), (o):start_kernel_secondary()]
* @init_machine: arch initcall level callback (e.g. populate static